@@ -6,11 +6,11 @@ from .connection import join_url
 from .connection import root
 from .exceptions import _raise_exception
 from .parse import BeautifulSoup
+from .parse import Tag
 from .parse import check_page_raise
 from .parse import html_to_bbcode
 from .parse import parse_user_page
 from .parse import parse_user_tag
-from .parse import Tag
 from .parse import username_url
 
 
@@ -38,6 +38,9 @@ class UserBase:
         self.name: str = ""
         self.status: str = ""
 
+    def __hash__(self) -> int:
+        return hash(self.name_url)
+
     def __eq__(self, other) -> bool:
         if isinstance(other, UserBase):
             return other.name_url == self.name_url
@@ -101,6 +104,14 @@ class UserBase:
         """
         return join_url(root, "user", self.name_url)
 
+    def generate_user_icon_url(self) -> str:
+        """
+        Generate the URl for the current user icon.
+
+        :return: The URL to the user icon
+        """
+        return f"https://a.furaffinity.net/{datetime.now():%Y%m%d}/{self.name_url}.gif"
+
 
 class UserPartial(UserBase):
     """
@@ -197,7 +208,12 @@ class User(UserBase):
 
     @property
     def profile_bbcode(self) -> str:
-        return html_to_bbcode(self.profile, special_characters=True)
+        """
+        The user profile text formatted to BBCode
+
+        :return: BBCode profile
+        """
+        return html_to_bbcode(self.profile)
 
     def parse(self, user_page: BeautifulSoup = None):
         """
